[
  'Person' => [
    [
      'name',
      'age',
      'email'
    ],
    [
      'Mommy',
      '55',
      'mom@moms.com'
    ],
    [
      'Tommy',
      '8',
      'tommy@toms.com'
    ],
  ],
  'Company' => [
    [
      'name',
    ],
    [
      'Rockets',
    ],
    [
      'Sprockets',
    ],
  ],
];
